@@ -19,10 +19,10 @@ double theta_bar(arma::vec theta);
 arma::vec eigen_val(arma::mat X);
 arma::mat eigen_vec(arma::mat X);
 arma::mat mvrnorm_arma_eigen(int n, arma::vec mu, arma::mat sigma);
-NumericVector circ_coef_rcpp(double a1, double a2, double b1, double b2);
-NumericVector hmodeci(NumericVector x, double cip);
-double hmode(NumericVector x, double cip);
-NumericVector hmodeciC(NumericVector x, double cip);
-double hmodeC(NumericVector x, double cip);
+Rcpp::NumericVector circ_coef_rcpp(double a1, double a2, double b1, double b2);
+Rcpp::NumericVector hmodeci(Rcpp::NumericVector x, double cip);
+double hmode(Rcpp::NumericVector x, double cip);
+Rcpp::NumericVector hmodeciC(Rcpp::NumericVector x, double cip);
+double hmodeC(Rcpp::NumericVector x, double cip);
 
 #endif
